/*
Copyright (c) Members of the EGEE Collaboration. 2004. 
See http://www.eu-egee.org/partners/ for details on the copyright
holders.  

Licensed under the Apache License, Version 2.0 (the "License"); 
you may not use this file except in compliance with the License. 
You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0 

Unless required by applicable law or agreed to in writing, software 
distributed under the License is distributed on an "AS IS" BASIS, 
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
See the License for the specific language governing permissions and 
limitations under the License. 
*/
package org.glite.security;

import org.apache.axis.AxisFault;

import java.security.GeneralSecurityException;

import javax.xml.namespace.QName;


/**
 * This is a security exception which can be converted
 * into an Axis Fault and thrown across a SOAP communication.
 * Based on the <code>org.edg.data.util.FaultableException</code>.
 *
 * @author Niklas Karlsson
 */
public class SecurityException extends GeneralSecurityException {
    /** the serialVersionUID */
	private static final long serialVersionUID = 1831206086348108137L;

	/**
     * Constructs an <code>SecurityException</code> with the specified
     * detail message.
     * @param message the pfn
     */
    public SecurityException(final String message) {
        super(message);
    }

    /**
     * Return this exception as an AXIS Fault
     * @return the fault
     */
    public AxisFault asFault() {
        return makeFault(faultCode(), getMessage());
    }

    /**
     * Returns the fault as an Axis fault.
     * 
     * @param faultType the fault to wrap.
     * @param string the error message.
     * @return the fault wrapped as AxisFault.
     */
    protected AxisFault makeFault(final String faultType, final String string) {
        final AxisFault f = AxisFault.makeFault(this);
        f.setFaultCode(new QName("edg-java-security", faultType));
        f.setFaultString(string);

        //f.setFaultDetailString(this.getMessage());
        return f;
    }

    /**
     * The code for security faults.
     * @return the default code, "SECURITY".
     */
    public static String faultCode() {
        return "SECURITY";
    }
}


// EOF SecurityException.java
